@@ -110,16 +110,13 @@ class SQL:
             "distinct" in c.lower() for c in columns
         ):  # Check if "distinct" exists in any entry
             distinct = True
-            columns = [
-                c.replace("distinct", "", 1).strip() if "distinct" in c.lower() else c
-                for c in columns
-            ]
+            columns = [re.sub(r"(?i)\bdistinct\b", "", c).strip() for c in columns]
 
         processed_columns = []
         for col in columns:
             processed_columns.append(
                 th.resolve_references(
-                    col, options={"alias_column": True, "alias_table": True}
+                    col, options={"alias_column": True, "alias_table": True, bypass_on_error=True}
                 )
             )
 
